A Clojure parser and interpreter for the Google Common Expression Language (CEL) syntax as defined in https://github.com/google/cel-spec/blob/master/doc/langdef.md
A Clojure parser and interpreter for the Google Common Expression Language (CEL) syntax as defined in https://github.com/google/cel-spec/blob/master/doc/langdef.md
(eval-for program bindings)(eval-for program bindings opts)Evaluate a parsed program (as given by make-program) with
bindings. bindings is a map of bindings to install in the program's
namespace. opts is a map of the following keys:
| Option | Value | |--------------------+----------------------------------------------------------| | :throw-on-error? | Whether to throw on error results. Default: false | | :translate-result? | Whether to transform results into values. Default: true. |
Evaluate a parsed program (as given by `make-program`) with bindings. `bindings` is a map of bindings to install in the program's namespace. `opts` is a map of the following keys: | Option | Value | |--------------------+----------------------------------------------------------| | :throw-on-error? | Whether to throw on error results. Default: false | | :translate-result? | Whether to transform results into values. Default: true. |
(make-program input)Build a program from the given input string. Throws for invalid expressions.
Build a program from the given input string. Throws for invalid expressions.
(parse-eval input)(parse-eval config input)Merged parsing and evaluation of a CEL expression.
config accepts the following keys:
| Option | Value | |--------------------+----------------------------------------------------------| | :bindings | A map of bindings to install in the program's namespace | | :throw-on-error? | Whether to throw on error results. Default: false | | :translate-result? | Whether to transform results into values. Default: true. |
Merged parsing and evaluation of a CEL expression. `config` accepts the following keys: | Option | Value | |--------------------+----------------------------------------------------------| | :bindings | A map of bindings to install in the program's namespace | | :throw-on-error? | Whether to throw on error results. Default: false | | :translate-result? | Whether to transform results into values. Default: true. |
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |